#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

from cases import RAID0

class RAID5Runner(RAID0.RAID0Runner):
    def writeKickstart(self):
        fo = open("/tmp/kickstart.ks", "w")
        fo.write("clearpart --all\n")
        fo.write("zerombr\n")
        fo.write("part /boot --fstype=ext4 --size=500\n")
        fo.write("part swap --fstype=swap --recommended\n")
        fo.write("part raid.01 --size=2000\n")
        fo.write("part raid.02 --size=2000\n")
        fo.write("part raid.03 --size=2000\n")
        fo.write("part raid.04 --size=2000\n")
        fo.write("raid / --device=0 --level=RAID5 raid.01 raid.02 raid.03 raid.04\n")
        fo.close()

class RAID5TestCase(RAID0.RAID0TestCase):
    """Verify we have the following:

       - 500 MB /boot partition
       - swap partition with size inside our recommendations
       - four equally sized partitions with a RAID format
       - / on md0
    """
    def test_raid(self):
        # Check that we created four equally sized partitions of type mdmember.
        members = self.getDevs(self.state, format="mdmember")
        self.assert_(len(members) == 4,
                     "Partitioning did not create exactly four RAID members.")
        firstSize = members[0]["length"]
        for i in [1, 2, 3]:
            self.assert_(members[i]["length"] == firstSize,
                         "Partitioning did not create equal sized RAID members: %s." % i)

        # Check that we created a RAID5 device.
        raid = self.single(self.getDevs(self.state, type="mdarray"))
        self.assert_(raid["level"] == 5,
                     "Device is not RAID5.")
