#!/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/audit/Sanity/initscript
#   Description: Make sure audit complies to guidelines for SysV-style Initscripts.
#   Author: Eduard Benes <ebenes@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2010 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/lib/beakerlib/beakerlib.sh
. /usr/share/beakerlib/beakerlib.sh 

PACKAGE="audit"
SERVICE="auditd"

rlJournalStart

    rlPhaseStartSetup
        rlAssertRpm $PACKAGE
        rlRun 'adduser testuserqa'
        rlServiceStop $SERVICE
    rlPhaseEnd

    rlPhaseStartTest
        rlLog ">>>>>>>>> service start"
          rlRun "service $SERVICE start" 0 " Service must start without problem"
          rlRun "service $SERVICE status" 0 " Then Status command "
          rlRun "service $SERVICE start" 0 " Already started service "
          rlRun "service $SERVICE status" 0 " Again status command "

        rlLog ">>>>>>>>> service restart"
          rlRun "service $SERVICE restart" 0 " Restarting of service"
          rlRun "service $SERVICE status" 0 " Status command "

        rlLog ">>>>>>>>> service stop"
          rlRun "service $SERVICE stop" 0 " Stopping service "
          rlRun "service $SERVICE status" 3 " Status of stopped service "
          rlRun "service $SERVICE stop" 0 " Stopping service again "
          rlRun "service $SERVICE status" 3 " Status of stopped service "

        rlLog ">>>>>>>>> pid file"
          service $SERVICE start
          rlAssertExists "/var/run/$SERVICE.pid" "Pid file /var/run/$SERVICE.pid must exist"
          service $SERVICE stop
          rlRun "echo 666666 > /var/run/$SERVICE.pid"
          rlRun "service $SERVICE status" 1 " Existing pid file, but service not started "
          service $SERVICE stop
          rm -fv /var/run/$SERVICE.pid

        rlLog ">>>>>>>>> lock file"
          service $SERVICE start
          rlAssertExists "/var/lock/subsys/$SERVICE" "Lock file /var/lock/subsys/$SERVICE must exist"
          service $SERVICE stop    
          rlRun "touch /var/lock/subsys/$SERVICE"  
          rlRun "service $SERVICE status" 2 " Existing lock file, but service not started " 
          service $SERVICE stop    
          rm -fv /var/lock/subsys/$SERVICE 

        rlLog ">>>>>>>>> insufficient rights"
          rlRun "service $SERVICE start " 0 " Starting service for restarting under non-priv. user."
          rlRun "su testuserqa -c 'service $SERVICE restart'" 0,4 "Insufficient rights, restarting service under non-privileged user must fail."              

        rlLog ">>>>>>>>> operations"
          rlRun "service $SERVICE start" 0 " Service have to implement start function."
          rlRun "service $SERVICE restart" 0 " Service have to implement restart function."
          rlRun "service $SERVICE status" 0 " Service have to implement status function."
          rlRun "service $SERVICE condrestart" 0,3 " Service have to implement condrestart function."
          rlRun "service $SERVICE try-restart" 0,3 " Service have to implement try-restart function."
          rlRun "service $SERVICE reload" 0,3 " Service have to implement reload function."
          rlRun "service $SERVICE force-reload" 0,3 " Service have to implement force-reload function."

        rlLog ">>>>>>>>> nonexist operations"
          rlRun "service $SERVICE noexistop" 2,3 " Testing proper return code when nonexisting function."

        rlLog ">>>>>>>>> invalid arguments" 
          rlRun "service $SERVICE" 2,3 " When no arguments added to service, it must fail with proper return code."
    rlPhaseEnd

    rlPhaseStartCleanup
        rlRun 'userdel -rf testuserqa'
	rlServiceRestore $SERVICE
    rlPhaseEnd
rlJournalPrintText
rlJournalEnd

