#!/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/avahi/Sanity/initscript
#   Description: Check if init scripts return correct exit codes
#   Author: Yulia Kopkova <ykopkova@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh
. /usr/share/beakerlib/beakerlib.sh

PACKAGE="avahi"

rlJournalStart
    rlPhaseStartSetup
        rlAssertRpm "avahi"
        rlAssertRpm "avahi-dnsconfd"
        rlRun "TmpDir=\`mktemp -d\`" 0 "Creating tmp directory"
        rlRun "pushd $TmpDir"
        rlRun "useradd testuserqa" 0 "Add test user"
    rlPhaseEnd

    for SERVICE in avahi-daemon avahi-dnsconfd; do
        rlPhaseStartSetup "$SERVICE - prepare"
            rlServiceStop $SERVICE
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - Mandatory actions"    
            for ACTION in "start" "stop" "restart" "force-reload" "status" ; do
                rlRun "grep -i \"usage.*$ACTION\" /etc/init.d/$SERVICE"
            done
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - start"    
            if [ $SERVICE == "avahi-dnsconfd" ] ; then
                rlServiceStart avahi-daemon
            fi
            
            rlRun "service $SERVICE start" 0 " Service must start without problem"
            rlRun "service $SERVICE status" 0 " Then Status command "
            rlRun "service $SERVICE start" 0 " Already started service "
            rlRun "service $SERVICE status" 0 " Again status command "
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - restart"    
            rlRun "service $SERVICE restart" 0 " Restarting of service"
            rlRun "service $SERVICE status" 0 " Status command "
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - stop"    
            rlRun "service $SERVICE stop" 0 " Stopping service "
            rlRun "service $SERVICE status" 3 " Status of stopped service "
            rlRun "service $SERVICE stop" 0 " Stopping service again "
            rlRun "service $SERVICE status" 3 " Status of stopped service "
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - pid"    
            if [ $SERVICE == "avahi-daemon" ] ; then
                PID_FILE="/var/run/avahi-daemon/pid"
            elif [ $SERVICE == "avahi-dnsconfd" ] ; then
                PID_FILE="/var/run/avahi-dnsconfd.pid"
            fi
	    rlRun "touch $PID_FILE"
            rlRun "service $SERVICE status" 1 " Existing pid file, but service not started "
            rlRun "rm -fv $PID_FILE" 0 "Remove .pid file"
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - lock"    
	    LOCK_FILE="/var/lock/subsys/$SERVICE"
	    rlRun "touch $LOCK_FILE"
            rlRun "service $SERVICE status" 2 " Existing lock file, but service not started "
            rlRun "rm -fv $LOCK_FILE" 0 "Remove lock file"
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - insufficient rights"    
            rlRun "service $SERVICE start " 0 " Starting service for restarting under nonpriv user "
            rlRun "su testuserqa -c 'service $SERVICE restart'" 1,4 "Insufficient rights, restarting service under nonprivileged user must fail"
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - operations"    
            rlRun "service $SERVICE start" 0 " Service have to implement start function "
            rlRun "service $SERVICE restart" 0 " Service have to implement restart function "
            rlRun "service $SERVICE status" 0 " Service have to implement status function "
            rlRun "service $SERVICE condrestart" 0 " Service have to implement condrestart function "
            rlRun "service $SERVICE try-restart" 0 " Service have to implement try-restart function "
            rlRun "service $SERVICE reload" 0 " Service have to implement reload function "
            rlRun "service $SERVICE force-reload" 0 " Service have to implement force-reload function "
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - invalid operation"    
            rlRun "service $SERVICE noexistop" 2 " Testing proper return code when nonexisting function"
        rlPhaseEnd

        rlPhaseStartTest "$SERVICE - invalid argument"    
            rlRun "service $SERVICE" 2 " When no arguments added to service, it must fail with proper return code "
        rlPhaseEnd
    
        rlPhaseStartCleanup "$SERVICE - Restore service"
            rlServiceRestore $SERVICE
        rlPhaseEnd
    done

    rlPhaseStartCleanup "Restore config"
        rlRun "popd"
        rlRun "rm -r $TmpDir" 0 "Removing tmp directory"
        rlRun "userdel -fr testuserqa" 0 "Remove test user"
    rlPhaseEnd

rlJournalPrintText
rlJournalEnd
