#!/bin/bash
# vim: dict=/usr/share/rhts-library/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/mcstrans/Sanity/init-scripts-LSB
#   Description: init scripts must meet LSB specifications
#   Author: Milos Malik <mmalik@redhat.com>
#           Martin Krizek <mkrizek@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh
. /usr/share/beakerlib/beakerlib.sh

PACKAGE="mcstrans"
SERVICE="mcstrans"
LOCKFILE="/var/lock/subsys/${SERVICE}d"
PIDFILE="/var/run/mcstransd.pid"

rlJournalStart
    rlPhaseStartSetup
        rlAssertRpm $PACKAGE
        USAGE_FILE=`mktemp`
        CASE_FILE=`mktemp`
	rlServiceStop $SERVICE
    rlPhaseEnd

    rlPhaseStartTest "Mandatory actions"
        for ACTION in "start" "stop" "restart" "force-reload" "status" ; do
            rlRun "grep -i \"usage.*$ACTION\" /etc/init.d/$SERVICE"
        done
    rlPhaseEnd

    rlPhaseStartTest "Recognized actions"
        LINES_COUNT=`wc -l < /etc/init.d/$SERVICE`
        LAST_CASE=`grep -n case /etc/init.d/$SERVICE | tail -n 1 | cut -d ':' -f 1`
        rlRun "tail -n $((LINES_COUNT - LAST_CASE)) /etc/init.d/$SERVICE | grep '[ 	]*[|a-zA-Z-]*)' | cut -d ')' -f 1 | tr '|' '\n' | tr -d ' 	' | grep -v '*' | sort > $CASE_FILE"
        rlRun "grep -i usage /etc/init.d/$SERVICE | cut -d '{' -f 2 | tr -d '}\"' | tr '|' '\n' | sort > $USAGE_FILE"
        rlRun "diff $CASE_FILE $USAGE_FILE"
    rlPhaseEnd

    rlPhaseStartTest "Required actions"
        rlRun "service $SERVICE start" 0 "Service must implement start action"
        rlRun "service $SERVICE stop" 0 "Service must implement stop action"
        rlRun "service $SERVICE restart" 0 "Service must implement restart action"
        rlRun "service $SERVICE condrestart" 0 "Service must implement condrestart action"
        rlRun "service $SERVICE try-restart" 0 "Service must implement try-restart action"
        rlRun "service $SERVICE reload" 0 "Service must implement reload action"
        rlRun "service $SERVICE force-reload" 0 "Service must implement force-reload action"
        rlRun "service $SERVICE status" 0 "Service must implement status action"
        rlRun "service $SERVICE usage" 0 "Service must implement usage action"
    rlPhaseEnd


    rlPhaseStartTest "Start"
        rlRun "service $SERVICE start" 0
        rlAssertExists "${PIDFILE}"
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE restart" 0
        rlRun "service $SERVICE status" 0
    rlPhaseEnd

    rlPhaseStartTest "Stop"
        rlRun "service $SERVICE stop" 0
        rlAssertNotExists "${PIDFILE}"
        rlRun "service $SERVICE status" 3
        rlRun "service $SERVICE stop" 0
        rlRun "service $SERVICE status" 3
    rlPhaseEnd

    rlPhaseStartTest "Lock file"
        rlRun "touch ${LOCKFILE}"
        rlRun "service $SERVICE status" 2,3
    rlPhaseEnd

    rlPhaseStartTest "PID file"
        rlRun "touch ${PIDFILE}"
        rlRun "service $SERVICE status" 1
    rlPhaseEnd

    rlPhaseStartTest "Condrestart"
        rlRun "service $SERVICE condrestart" 0
        rlRun "service $SERVICE status" 0
    rlPhaseEnd

    rlPhaseStartTest "Insufficient arguments"
        rlRun "service $SERVICE" 2,3
    rlPhaseEnd

    rlPhaseStartCleanup
        rlRun "rm -f ${LOCKFILE}"
        rlRun "rm -f ${PIDFILE}"
        rm -f $USAGE_FILE
        rm -f $CASE_FILE
	rlServiceRestore $SERVICE
    rlPhaseEnd
rlJournalPrintText
rlJournalEnd

