#!/bin/bash
# vim: dict=/usr/share/rhts-library/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/tigervnc/Sanity/initscript
#   Description: Initscript sanity
#   Author: Radek Biba <rbiba@redhat.com>
#           Martin Krizek <mkrizek@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh
. /usr/share/beakerlib/beakerlib.sh

PACKAGE="tigervnc"
SERVICE="vncserver"
SERVICE_LOCKING_ALIAS="Xvnc"
CONFIG="/etc/sysconfig/vncservers"
TESTUSER="qa"

rlJournalStart
    rlPhaseStartSetup "Prepare"
        rlServiceStop $SERVICE
        rlFileBackup $CONFIG
        rlRun "useradd $TESTUSER"
        rlRun "runuser -l $TESTUSER -c \"mkdir .vnc; cd .vnc; umask 066; touch xstartup passwd\""
        rlRun "> $CONFIG"
    rlPhaseEnd

    rlPhaseStartTest "Mandatory actions"
        for ACTION in "start" "stop" "restart" "force-reload" "try-restart" "status" ; do
            rlRun "grep -i \"usage.*$ACTION\" /etc/init.d/$SERVICE"
        done
    rlPhaseEnd

    rlPhaseStartTest "Required actions"
	# avoiding "service is not configured" status"
        rlRun "echo VNCSERVERS=7:$TESTUSER > $CONFIG"
        rlRun "service $SERVICE start" 0 "Service must implement start action"
        rlRun "service $SERVICE stop" 0 "Service must implement stop action"
        rlRun "service $SERVICE restart" 0 "Service must implement restart action"
        rlRun "service $SERVICE condrestart" 0 "Service must implement condrestart action"
        rlRun "service $SERVICE try-restart" 0 "Service must implement try-restart action"
        rlRun "service $SERVICE reload" 0 "Service must implement reload action"
        rlRun "service $SERVICE force-reload" 0 "Service must implement force-reload action"
        rlRun "service $SERVICE status" 0 "Service must implement status action"
	# delete config file after status check
        rlRun "rm -f $CONFIG"
    rlPhaseEnd

    rlPhaseStartTest "Start"
# Examine behavior of unconfigured service first.
        rlRun "service $SERVICE start" 6
# Configure it and begin testing as usual.
        rlRun "echo VNCSERVERS=7:$TESTUSER > $CONFIG"
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE restart" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE force-reload" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE try-restart" 0
        rlRun "service $SERVICE status" 0
    rlPhaseEnd
    rlPhaseStartTest "Stop"
        rlRun "service $SERVICE stop" 0
        rlRun "service $SERVICE status" 3
        rlRun "service $SERVICE stop" 0
        rlRun "service $SERVICE status" 3
        rlRun "service $SERVICE try-restart" 0
        rlRun "service $SERVICE status" 3
    rlPhaseEnd
    rlPhaseStartTest "Dead service"
        rlRun "touch /var/lock/subsys/$SERVICE_LOCKING_ALIAS"
        rlRun "service $SERVICE status" 2
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE status" 0
    rlPhaseEnd
    rlPhaseStartTest "Invalid arguments"
        rlRun "service $SERVICE" 2
        rlRun "service $SERVICE fubar" 2
    rlPhaseEnd

    rlPhaseStartCleanup "Restore"
        rlServiceRestore $SERVICE
        rlFileRestore
        rlRun "userdel -r $TESTUSER"
    rlPhaseEnd
rlJournalPrintText
rlJournalEnd
