#!/bin/bash
# vim: dict=/usr/share/rhts-library/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/udev/Sanity/init-script-LSB
#   Description: Init script should meet LSB specifications
#   Author: Jan Scotka <jscotka@redhat.com>, Yulia Kopkova <ykopkova@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh

. /usr/share/beakerlib/beakerlib.sh

PACKAGE="udev"

SERVICE="udev-post"

rlJournalStart
    
    rlPhaseStartSetup
        rlAssertRpm $PACKAGE
        rlRun "useradd testuserqa" 0 "Add test user"
        rlServiceStop $SERVICE
    rlPhaseEnd

    rlPhaseStartTest

        rlLog ">>>>>>>>> service start"
        rlRun "service $SERVICE start" 0 " Service must start without problem"

        rlLog ">>>>>>>>> service stop"
        rlRun "service $SERVICE stop" 0 " Stopping service "
        rlRun "service $SERVICE status" 3 " Status of stopped service "

#        Could fail because in one case start action do not create a lock file
#        rlLog ">>>>>>>>> lock file"
#        rlServiceStart $SERVICE
#        rlAssertExists "/var/lock/subsys/$SERVICE" "Lock file /var/lock/subsys/$SERVICE must exist"

        rlLog ">>>>>>>>> insufficient rights"
        rlRun "su testuserqa -c 'service $SERVICE start'" 4 "Insufficient rights, starting service under nonprivileged user must fail"
        rlRun "su testuserqa -c 'service $SERVICE stop'" 4 "Insufficient rights, stopping service under nonprivileged user must fail"
        
        rlLog ">>>>>>>>> operations"
        rlRun "service $SERVICE start" 0 " Service have to implement start function "
        rlRun "service $SERVICE status" 3 " Service have to implement status function "
        rlRun "service $SERVICE reload" 0 " Service have to implement reload function "

        rlLog ">>>>>>>>> nonexist operations"
        rlRun "service $SERVICE noexistop" 2 " Testing proper return code when nonexisting function"

    rlPhaseEnd

    rlPhaseStartCleanup
        rlServiceRestore $SERVICE
        rlRun "userdel -fr testuserqa" 0 "Remove test user"
    rlPhaseEnd

rlJournalPrintText
rlJournalEnd
