#!/usr/bin/python
#
# Copyright 2009, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Author: Will Woods <wwoods@redhat.com>

import os
from random import randint
from SimpleXMLRPCServer import SimpleXMLRPCServer

def emptydir(dir):
    for f in [os.path.join(dir,name) for name in os.listdir(dir)]:
        if os.path.isfile(f):
            os.remove(f)

token_char = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"
def randtoken(length=10):
    return "".join([token_char[randint(0,63)] for i in range(0,length)])

class MinimonServer(object):
    def __init__(self, host='0.0.0.0', port=0, token='', logdir='/tmp/minimon'):
        self.host = host
        self.port = port
        self.token = token or randtoken()
        self.logdir = logdir
        self.server = SimpleXMLRPCServer((self.host, self.port))
        self.server.logRequests = False
        # binding to port 0 gets you a random port, so find out what we got 
        (self.host, self.port) = self.server.socket.getsockname()
    def get_config(self):
        return (self.host, self.port, self.token)
    def start(self):
        def do_log(token, basename, data): # data = xmlrpclib.Binary object
            return self.log(token, basename, data.data)
        self.server.register_function(do_log, name='log')
        if os.path.isdir(self.logdir):
            emptydir(self.logdir)
        else:
            if os.path.exists(self.logdir):
                os.unlink(self.logdir)
            os.makedirs(self.logdir, mode=0755) # XXX reconsider mode
    def log(self, token, basename, data):
        '''Actual log function exported to clients.'''
        if '/' in basename or data == '' or token != self.token:
            return 0 # XXX raise a Fault instead?
        logfile = os.path.join(self.logdir, basename)
        try:
            outf = open(logfile, "a")
            outf.write(data)
            outf.close()
        except IOError:
            return 0 # XXX raise Fault?
        return len(data)

if __name__ == '__main__':
    minimon = MinimonServer()
    minimon.start()
    (host, port, token) = minimon.get_config()
    print "MinimonServer listening on %s:%u %s" % (host, port, token)
    print "  logfiles written to %s/" % minimon.logdir
    try:
        minimon.server.serve_forever()
    except KeyboardInterrupt:
        print "MinimonServer shutting down."
